@@ -15,18 +15,18 @@ class ModifySecurityGroupAttributesAction(BaseAction):
                 help='the ID of the security group you want to update its content.')
 
         parser.add_argument('-N', '--security_group_name', dest='security_group_name',
-                action='store', type=str, default='',
+                action='store', type=str, default=None,
                 help='the new name for the security group you want to update.')
 
         parser.add_argument('-D', '--description', dest='description',
-                action='store', type=str, default='',
+                action='store', type=str, default=None,
                 help='the detailed description of the resource')
 
     @classmethod
     def build_directive(cls, options):
         required_params = {
                 'security_group_id': options.security_group_id,
-                } 
+                }
         for param in required_params:
             if required_params[param] is None or required_params[param] == '':
                 print 'param [%s] should be specified' % param
